# LibFile: metalib.scad


To use, add the following lines to the beginning of your file:

    include <Metalib/metalib.scad>;

## File Contents

- [`miter_profile()`](#module-miter_profile) – Creates a miter profile
- [`miter_tubes()`](#module-miter_tubes) – Generates a sequence of mitered tubes


### Module: miter\_profile()

**Synopsis:** Creates a miter profile

**Topics:** [Metal](Topics#metal)

**Usage:** As Module

- miter_profile(length,height,depth);

**Description:** 

Generates a flexible battery holder for 'n' cylindrical batteries with complex features like wire channels, screw holes, and contact points.


This is the continues content

**Side Effects:** 

- No side effects registered

**Arguments:** 

<abbr title="These args can be used by position or by name.">By&nbsp;Position</abbr> | What it does
-------------------- | ------------
`length`             | Length
`height`             | Height
`depth`              | Depth

**Example 1:** Simple Case

<img align="left" alt="miter\_profile() Example 1" src="images/metalib/miter_profile.png" width="320" height="240">

    include <Metalib/metalib.scad>;
    miter_profile(length=200, height=30, depth=20);

<br clear="all" /><br/>

---

### Module: miter\_tubes()

**Synopsis:** Generates a sequence of mitered tubes

**Topics:** [Metal](Topics#metal)

**Description:** 

This module generates a sequence of mitered tubes based on the provided section lengths,
      with options for customizing their dimensions and unfolding their arrangement.

**Arguments:** 

<abbr title="These args can be used by position or by name.">By&nbsp;Position</abbr> | What it does
-------------------- | ------------
`section`            | An array of section lengths, each specifying the length of an individual tube. Example: `[10, 20, 30]` will create three tubes of lengths 10, 20, and 30 units respectively.
`heights`            | The height of each tube. This value defines the dimension perpendicular to the tube's length and depth.
`depth`              | The depth of each tube. This value defines the dimension perpendicular to the tube's length and height.

<abbr title="These args must be used by name, ie: name=value">By&nbsp;Name</abbr> | What it does
-------------------- | ------------
`unfold`             | Determines whether the sequence of tubes should be unfolded for easier visualization or fabrication. When `true`, the tubes are laid out in a flat arrangement. Defaults to `false`.

**Example 1:** Simple Case

<img align="left" alt="miter\_tubes() Example 1" src="images/metalib/miter_tubes.png" width="320" height="240">

    include <Metalib/metalib.scad>;
    miter_tubes(
         sections = [800,750,800],
         height = 50,
         depth = 50,
         start=false,
         end=false,
         unfold = false,
         quote=false
     );

<br clear="all" /><br/>

**Example 2:** Unfolded and Quoted

<img align="left" alt="miter\_tubes() Example 2" src="images/metalib/miter_tubes_2.png" width="320" height="240">

    include <Metalib/metalib.scad>;
    miter_tubes(
         sections = [800,750],
         height = 50,
         depth = 50,
         unfold = true,
         quote=true
     );

<br clear="all" /><br/>

---

